pub struct ScaleRange {
pub start: f64,
pub end: f64,
pub end_included: bool,
}Fields
start: f64end: f64end_included: boolImplementations
Sourceimpl ScaleRange
impl ScaleRange
pub fn new<R: RangeBounds<f64>>(range: R) -> Self
pub fn as_range(&self) -> Range<f64>
pub fn span(&self) -> f64
pub fn scale(&self, value: f64) -> f64
pub fn unscale(&self, value: f64) -> f64
pub fn scale_descent(&self, value: f64) -> f64
pub fn unscale_descent(&self, value: f64) -> f64
Sourcepub fn iter_with_step(&self, step: f64) -> ScaleRangeIterator ⓘ
pub fn iter_with_step(&self, step: f64) -> ScaleRangeIterator ⓘ
Creates an iterator over the range with a specified step size. Produces values aligned with the step size, for use to draw grid lines and ticks.