Module layer

Module layer 

Layer module for SVG rendering

This module provides the Layer struct, which represents a layer in an SVG document. It allows adding SVG nodes, setting attributes, and provides methods for rendering.

Structs

Layer