delegate_xy_chart_methods

Macro delegate_xy_chart_methods 

macro_rules! delegate_xy_chart_methods {
    ($struct_type:ty, $field:ident) => { ... };
}
Macro to delegate all XYChart methods to a field of a struct, to avoid using Deref and DerefMut Add methods here when adding new methods to XYChart Usage: delegate_xy_chart_methods!(MyStruct, chart_field);