Module svgdoc

Module svgdoc 

SVG document representation and rendering.

This module provides the SvgDocument struct, which allows you to create and manipulate SVG documents and render them to SVG files. It includes methods for adding clip paths, symbols, and plots, as well as setting the document’s width, height, and margin.

Structs

SvgDocument
Represents an SVG document with a specified width and height. It contains clip paths, styles, layers, and symbols that can be used to create SVG graphics. Although you can directly manipulate the SVG document, it is recommended to use higher level objects in this library such as Chart struct for creating scaled charts with x and y axis.

Constants

EAST
NORTH
NORTH_EAST
NORTH_WEST
SOUTH
SOUTH_EAST
SOUTH_WEST
WEST