Style attributes for SVG elements in the plotting library
The StyleAttr struct and associated macros are used to manage SVG style attributes such as
CSS classes, inline styles, and IDs. This allows for easy styling of SVG elements in plots.
Structs
- Style
Attr - Represents SVG style attributes, including optional class, style, and id fields.
Functions
- class
- Creates a new
StyleAttrwith the specified class. This function is a convenience method to create aStyleAttrinstance with theclassfield set. - id
- Creates a new
StyleAttrwith the specified id. This function is a convenience method to create aStyleAttrinstance with theidfield set. - style
- Creates a new
StyleAttrwith the specified style. This function is a convenience method to create aStyleAttrinstance with thestylefield set.